@@ -5,10 +5,10 @@ import (
 
 	"github.com/stretchr/testify/assert"
 
+	"github.com/anchore/grype/grype/distro"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/internal"
-	"github.com/anchore/syft/syft/distro"
 	syftPkg "github.com/anchore/syft/syft/pkg"
 )
 
@@ -23,13 +23,13 @@ func TestMatcherDpkg_matchBySourceIndirection(t *testing.T) {
 		},
 	}
 
-	d, err := distro.NewDistro(distro.Debian, "8", "")
+	d, err := distro.New(distro.Debian, "8", "")
 	if err != nil {
 		t.Fatal("could not create distro: ", err)
 	}
 
 	store := newMockProvider()
-	actual, err := matcher.matchBySourceIndirection(store, &d, p)
+	actual, err := matcher.matchBySourceIndirection(store, d, p)
 
 	assert.Len(t, actual, 2, "unexpected indirect matches count")
 
