@@ -6,7 +6,7 @@ import (
 	"sort"
 	"strings"
 
-	grypeDb "github.com/anchore/grype-db/pkg/db/v3"
+	grypeDb "github.com/anchore/grype/grype/db/v3"
 	"github.com/anchore/grype/grype/match"
 	"github.com/anchore/grype/grype/pkg"
 	"github.com/anchore/grype/grype/vulnerability"
